# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from termcolor import cprint


def print_debug(component, *msg):
    """Print debug message

    Args:
        component (str): Origin component.
        msg (*str): Debug message. Can be made of multiple chunk like
        a normal print.
    """
    msg = " ".join(str(m) for m in msg)
    cprint('[DEBUG]%s:%s' % (component, msg))
